@@ -1,4 +1,4 @@
-import sys
+import sys, os
 from easysettings import EasySettings
 from pathlib import Path
 from .serve import serve_local_model
@@ -8,8 +8,8 @@ settings = EasySettings(str(Path.home()) + "/.inferrd.conf")
 def main():
   command = sys.argv[1]
 
-  if(command != 'auth' and command != 'serve'):
-    print('The only command available are "auth" and "serve"')
+  if(command != 'auth' and command != 'serve' and command != 'init' and command != 'deploy'):
+    print('The only command available are "auth", "serve", "init" and "deploy"')
     exit()
 
   if(len(sys.argv) == 2 and command == 'auth'):
@@ -19,6 +19,9 @@ def main():
   if(command == 'serve'):
     serve_local_model()
 
+  if(command == 'init'):
+    os.system('git clone https://github.com/inferrd/custom-environment-example')
+
   if(command == 'auth'):
     api_key = sys.argv[2]
     settings.set('api_key', api_key)
