@@ -4,11 +4,12 @@ import sys
 
 def serve_local_model():
   print('> Adding this directory to python path')
-  sys.path.insert(1, os.getcwd())
+  print(os.getcwd())
+  sys.path.insert(0, os.getcwd())
   # check that files exist
   print('> Loading predictor.py...')
   try:
-    from .predictor import Predictor
+    from predictor import Predictor
   except Exception as e:
     print('> Errror! Could not load predictor.py:')
     print(str(e))
